Class: OneSignal::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/onesignal/configuration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|_self| ... } ⇒ Configuration

Returns a new instance of Configuration.

Yields:

  • (_self)

Yield Parameters:



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/onesignal/configuration.rb', line 116

def initialize
  @scheme = 'https'
  @host = 'api.onesignal.com'
  @base_path = ''
  @server_index = 0
  @server_operation_index = {}
  @server_variables = {}
  @server_operation_variables = {}
  @timeout = 0
  @client_side_validation = true
  @verify_ssl = true
  @verify_ssl_host = true
  @cert_file = nil
  @key_file = nil
  @timeout = 0
  @params_encoding = nil
  @debugging = false
  @inject_format = false
  @force_ending_format = false
  @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT)

  yield(self) if block_given?
end

Instance Attribute Details

#base_pathObject

Defines url base path



21
22
23
# File 'lib/onesignal/configuration.rb', line 21

def base_path
  @base_path
end

#cert_fileObject

TLS/SSL setting Client certificate file (for client certificate)



98
99
100
# File 'lib/onesignal/configuration.rb', line 98

def cert_file
  @cert_file
end

#client_side_validationtrue, false

Set this to false to skip client side validation in the operation. Default to true.

Returns:

  • (true, false)


67
68
69
# File 'lib/onesignal/configuration.rb', line 67

def client_side_validation
  @client_side_validation
end

#debuggingtrue, false

Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with logger.debug (see the logger attribute). Default to false.

Returns:

  • (true, false)


45
46
47
# File 'lib/onesignal/configuration.rb', line 45

def debugging
  @debugging
end

#force_ending_formatObject

Returns the value of attribute force_ending_format.



114
115
116
# File 'lib/onesignal/configuration.rb', line 114

def force_ending_format
  @force_ending_format
end

#hostObject

Defines url host



18
19
20
# File 'lib/onesignal/configuration.rb', line 18

def host
  @host
end

#inject_formatObject

Returns the value of attribute inject_format.



112
113
114
# File 'lib/onesignal/configuration.rb', line 112

def inject_format
  @inject_format
end

#key_fileObject

TLS/SSL setting Client private key file (for client certificate)



102
103
104
# File 'lib/onesignal/configuration.rb', line 102

def key_file
  @key_file
end

#logger#debug

Defines the logger used for debugging. Default to Rails.logger (when in Rails) or logging to STDOUT.

Returns:

  • (#debug)


51
52
53
# File 'lib/onesignal/configuration.rb', line 51

def logger
  @logger
end

#organization_api_keyObject

Returns the value of attribute organization_api_key.



35
36
37
# File 'lib/onesignal/configuration.rb', line 35

def organization_api_key
  @organization_api_key
end

#params_encodingObject

Set this to customize parameters encoding of array parameter with multi collectionFormat. Default to nil.

https://github.com/typhoeus/ethon/blob/master/lib/ethon/easy/queryable.rb#L96

See Also:

  • params_encoding option of Ethon. Related source code:


109
110
111
# File 'lib/onesignal/configuration.rb', line 109

def params_encoding
  @params_encoding
end

#rest_api_keyObject

Returns the value of attribute rest_api_key.



37
38
39
# File 'lib/onesignal/configuration.rb', line 37

def rest_api_key
  @rest_api_key
end

#schemeObject

Defines url scheme



15
16
17
# File 'lib/onesignal/configuration.rb', line 15

def scheme
  @scheme
end

#server_indexObject

Define server configuration index



24
25
26
# File 'lib/onesignal/configuration.rb', line 24

def server_index
  @server_index
end

#server_operation_indexObject

Define server operation configuration index



27
28
29
# File 'lib/onesignal/configuration.rb', line 27

def server_operation_index
  @server_operation_index
end

#server_operation_variablesObject

Default server operation variables



33
34
35
# File 'lib/onesignal/configuration.rb', line 33

def server_operation_variables
  @server_operation_variables
end

#server_variablesObject

Default server variables



30
31
32
# File 'lib/onesignal/configuration.rb', line 30

def server_variables
  @server_variables
end

#ssl_ca_certString

TLS/SSL setting Set this to customize the certificate file to verify the peer.

https://github.com/typhoeus/typhoeus/blob/master/lib/typhoeus/easy_factory.rb#L145

Returns:

  • (String)

    the path to the certificate file

See Also:

  • `cainfo` option of Typhoeus, `--cert` option of libcurl. Related source code:


94
95
96
# File 'lib/onesignal/configuration.rb', line 94

def ssl_ca_cert
  @ssl_ca_cert
end

#temp_folder_pathString

Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use Tempfile.

Returns:

  • (String)


58
59
60
# File 'lib/onesignal/configuration.rb', line 58

def temp_folder_path
  @temp_folder_path
end

#timeoutObject

The time limit for HTTP request in seconds. Default to 0 (never times out).



62
63
64
# File 'lib/onesignal/configuration.rb', line 62

def timeout
  @timeout
end

#verify_ssltrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.

Returns:

  • (true, false)


76
77
78
# File 'lib/onesignal/configuration.rb', line 76

def verify_ssl
  @verify_ssl
end

#verify_ssl_hosttrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.

Returns:

  • (true, false)


85
86
87
# File 'lib/onesignal/configuration.rb', line 85

def verify_ssl_host
  @verify_ssl_host
end

Class Method Details

.defaultObject

The default Configuration object.



141
142
143
# File 'lib/onesignal/configuration.rb', line 141

def self.default
  @@default ||= Configuration.new
end

Instance Method Details

#auth_settingsObject

Returns Auth Settings hash for api client.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/onesignal/configuration.rb', line 174

def auth_settings
  {
    'organization_api_key' =>
      {
        type: 'bearer',
        in: 'header',
        key: 'Authorization',
        value: "Key \"#{ organization_api_key }\""
      },
    'rest_api_key' =>
      {
        type: 'bearer',
        in: 'header',
        key: 'Authorization',
        value: "Key \"#{ rest_api_key }\""
      },
  }
end

#base_url(operation = nil) ⇒ Object

Returns base URL for specified operation based on server settings



166
167
168
169
170
171
# File 'lib/onesignal/configuration.rb', line 166

def base_url(operation = nil)
  index = server_operation_index.fetch(operation, server_index)
  return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if index == nil

  server_url(index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation])
end

#configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:



145
146
147
# File 'lib/onesignal/configuration.rb', line 145

def configure
  yield(self) if block_given?
end

#operation_server_settingsObject



203
204
205
206
# File 'lib/onesignal/configuration.rb', line 203

def operation_server_settings
  {
  }
end

#server_settingsObject

Returns an array of Server setting



194
195
196
197
198
199
200
201
# File 'lib/onesignal/configuration.rb', line 194

def server_settings
  [
    {
      url: "https://api.onesignal.com",
      description: "No description provided",
    }
  ]
end

#server_url(index, variables = {}, servers = nil) ⇒ Object

Returns URL based on server settings

Parameters:

  • index

    array index of the server settings

  • variables (defaults to: {})

    hash of variable and the corresponding value



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/onesignal/configuration.rb', line 212

def server_url(index, variables = {}, servers = nil)
  servers = server_settings if servers == nil

  # check array index out of bound
  if (index < 0 || index >= servers.size)
    fail ArgumentError, "Invalid index #{index} when selecting the server. Must be less than #{servers.size}"
  end

  server = servers[index]
  url = server[:url]

  return url unless server.key? :variables

  # go through variable and assign a value
  server[:variables].each do |name, variable|
    if variables.key?(name)
      if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name]))
        url.gsub! "{" + name.to_s + "}", variables[name]
      else
        fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}."
      end
    else
      # use default value
      url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value]
    end
  end

  url
end