Class: OneSignal::JourneyNode
- Inherits:
-
Object
- Object
- OneSignal::JourneyNode
- Defined in:
- lib/onesignal/models/journey_node.rb
Overview
A journey node. The kind field selects which other fields apply. Branching nodes (split_range, yes_no, wait_until) nest their sub-graphs inline via branches.nodes.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#annotation ⇒ Object
Optional free-text label, up to 255 characters.
-
#assignments ⇒ Object
tag nodes: tag key-value pairs to assign.
-
#branches ⇒ Object
Branching nodes: nested branches.
-
#client_node_id ⇒ Object
Optional client-assigned identifier, unique within the journey.
-
#duration_seconds ⇒ Object
wait nodes: seconds to hold the user.
-
#expiration ⇒ Object
Returns the value of attribute expiration.
-
#iam_id ⇒ Object
send_iam nodes: UUID of the in-app message to send.
-
#id ⇒ Object
Server-assigned node UUID.
-
#kind ⇒ Object
Node kind.
-
#randomize_on_entry ⇒ Object
split_range nodes: when true, assigns each user to a branch at random on entry.
-
#relative_to ⇒ Object
time_window nodes: schedule_in_timezone uses the configured windows; last_active_time holds relative to the user's last active time.
-
#template_id ⇒ Object
send_push, send_email, and send_sms nodes: UUID of the template to send.
-
#time_zone ⇒ Object
time_window nodes: IANA timezone identifier used when the user's timezone is unavailable.
-
#use_user_time_zone ⇒ Object
time_window nodes: when true, uses the user's timezone if available.
-
#user_ttl_seconds ⇒ Object
send_iam nodes: optional time-to-live for the in-app message, in seconds.
-
#webhook_id ⇒ Object
send_webhook nodes: UUID of the webhook to send.
-
#windows ⇒ Object
time_window nodes: one or more time windows.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JourneyNode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ JourneyNode
Initializes the object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/onesignal/models/journey_node.rb', line 154 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneSignal::JourneyNode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneSignal::JourneyNode`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'client_node_id') self.client_node_id = attributes[:'client_node_id'] end if attributes.key?(:'annotation') self.annotation = attributes[:'annotation'] end if attributes.key?(:'duration_seconds') self.duration_seconds = attributes[:'duration_seconds'] end if attributes.key?(:'relative_to') self.relative_to = attributes[:'relative_to'] end if attributes.key?(:'windows') if (value = attributes[:'windows']).is_a?(Array) self.windows = value end end if attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] end if attributes.key?(:'use_user_time_zone') self.use_user_time_zone = attributes[:'use_user_time_zone'] end if attributes.key?(:'template_id') self.template_id = attributes[:'template_id'] end if attributes.key?(:'iam_id') self.iam_id = attributes[:'iam_id'] end if attributes.key?(:'user_ttl_seconds') self.user_ttl_seconds = attributes[:'user_ttl_seconds'] end if attributes.key?(:'webhook_id') self.webhook_id = attributes[:'webhook_id'] end if attributes.key?(:'assignments') if (value = attributes[:'assignments']).is_a?(Hash) self.assignments = value end end if attributes.key?(:'randomize_on_entry') self.randomize_on_entry = attributes[:'randomize_on_entry'] end if attributes.key?(:'branches') if (value = attributes[:'branches']).is_a?(Array) self.branches = value end end if attributes.key?(:'expiration') self.expiration = attributes[:'expiration'] end end |
Instance Attribute Details
#annotation ⇒ Object
Optional free-text label, up to 255 characters. Stored and returned as-is with no effect on journey behavior.
28 29 30 |
# File 'lib/onesignal/models/journey_node.rb', line 28 def annotation @annotation end |
#assignments ⇒ Object
tag nodes: tag key-value pairs to assign. An empty string value removes the tag. Keys are limited to 255 characters and values to 1024.
58 59 60 |
# File 'lib/onesignal/models/journey_node.rb', line 58 def assignments @assignments end |
#branches ⇒ Object
Branching nodes: nested branches. split_range requires 2-20 weighted branches that sum to 100. yes_no requires exactly 2 branches. wait_until requires 1-10 condition branches.
64 65 66 |
# File 'lib/onesignal/models/journey_node.rb', line 64 def branches @branches end |
#client_node_id ⇒ Object
Optional client-assigned identifier, unique within the journey. Use it to reference this node from elsewhere in the same request. Persisted and returned on reads.
25 26 27 |
# File 'lib/onesignal/models/journey_node.rb', line 25 def client_node_id @client_node_id end |
#duration_seconds ⇒ Object
wait nodes: seconds to hold the user. Minimum 60, maximum 31556952 (1 year).
31 32 33 |
# File 'lib/onesignal/models/journey_node.rb', line 31 def duration_seconds @duration_seconds end |
#expiration ⇒ Object
Returns the value of attribute expiration.
66 67 68 |
# File 'lib/onesignal/models/journey_node.rb', line 66 def expiration @expiration end |
#iam_id ⇒ Object
send_iam nodes: UUID of the in-app message to send.
49 50 51 |
# File 'lib/onesignal/models/journey_node.rb', line 49 def iam_id @iam_id end |
#id ⇒ Object
Server-assigned node UUID. Returned on reads. Required on update to keep an existing node. Rejected on create with a 400 validation error.
19 20 21 |
# File 'lib/onesignal/models/journey_node.rb', line 19 def id @id end |
#kind ⇒ Object
Node kind. Selects which other fields apply.
22 23 24 |
# File 'lib/onesignal/models/journey_node.rb', line 22 def kind @kind end |
#randomize_on_entry ⇒ Object
split_range nodes: when true, assigns each user to a branch at random on entry. Defaults to false.
61 62 63 |
# File 'lib/onesignal/models/journey_node.rb', line 61 def randomize_on_entry @randomize_on_entry end |
#relative_to ⇒ Object
time_window nodes: schedule_in_timezone uses the configured windows; last_active_time holds relative to the user's last active time.
34 35 36 |
# File 'lib/onesignal/models/journey_node.rb', line 34 def relative_to @relative_to end |
#template_id ⇒ Object
send_push, send_email, and send_sms nodes: UUID of the template to send.
46 47 48 |
# File 'lib/onesignal/models/journey_node.rb', line 46 def template_id @template_id end |
#time_zone ⇒ Object
time_window nodes: IANA timezone identifier used when the user's timezone is unavailable.
40 41 42 |
# File 'lib/onesignal/models/journey_node.rb', line 40 def time_zone @time_zone end |
#use_user_time_zone ⇒ Object
time_window nodes: when true, uses the user's timezone if available.
43 44 45 |
# File 'lib/onesignal/models/journey_node.rb', line 43 def use_user_time_zone @use_user_time_zone end |
#user_ttl_seconds ⇒ Object
send_iam nodes: optional time-to-live for the in-app message, in seconds.
52 53 54 |
# File 'lib/onesignal/models/journey_node.rb', line 52 def user_ttl_seconds @user_ttl_seconds end |
#webhook_id ⇒ Object
send_webhook nodes: UUID of the webhook to send.
55 56 57 |
# File 'lib/onesignal/models/journey_node.rb', line 55 def webhook_id @webhook_id end |
#windows ⇒ Object
time_window nodes: one or more time windows. A window with no day_of_week applies to every day. Required when relative_to is schedule_in_timezone; omit when it is last_active_time.
37 38 39 |
# File 'lib/onesignal/models/journey_node.rb', line 37 def windows @windows end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
114 115 116 |
# File 'lib/onesignal/models/journey_node.rb', line 114 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/onesignal/models/journey_node.rb', line 91 def self.attribute_map { :'id' => :'id', :'kind' => :'kind', :'client_node_id' => :'client_node_id', :'annotation' => :'annotation', :'duration_seconds' => :'duration_seconds', :'relative_to' => :'relative_to', :'windows' => :'windows', :'time_zone' => :'time_zone', :'use_user_time_zone' => :'use_user_time_zone', :'template_id' => :'template_id', :'iam_id' => :'iam_id', :'user_ttl_seconds' => :'user_ttl_seconds', :'webhook_id' => :'webhook_id', :'assignments' => :'assignments', :'randomize_on_entry' => :'randomize_on_entry', :'branches' => :'branches', :'expiration' => :'expiration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
362 363 364 |
# File 'lib/onesignal/models/journey_node.rb', line 362 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
142 143 144 145 146 147 148 149 150 |
# File 'lib/onesignal/models/journey_node.rb', line 142 def self.openapi_nullable Set.new([ :'duration_seconds', :'use_user_time_zone', :'user_ttl_seconds', :'randomize_on_entry', :'expiration' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/onesignal/models/journey_node.rb', line 119 def self.openapi_types { :'id' => :'String', :'kind' => :'String', :'client_node_id' => :'String', :'annotation' => :'String', :'duration_seconds' => :'Integer', :'relative_to' => :'String', :'windows' => :'Array<JourneyTimeWindow>', :'time_zone' => :'String', :'use_user_time_zone' => :'Boolean', :'template_id' => :'String', :'iam_id' => :'String', :'user_ttl_seconds' => :'Integer', :'webhook_id' => :'String', :'assignments' => :'Hash<String, String>', :'randomize_on_entry' => :'Boolean', :'branches' => :'Array<JourneyBranch>', :'expiration' => :'JourneyWaitUntilExpiration' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/onesignal/models/journey_node.rb', line 325 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && kind == o.kind && client_node_id == o.client_node_id && annotation == o.annotation && duration_seconds == o.duration_seconds && relative_to == o.relative_to && windows == o.windows && time_zone == o.time_zone && use_user_time_zone == o.use_user_time_zone && template_id == o.template_id && iam_id == o.iam_id && user_ttl_seconds == o.user_ttl_seconds && webhook_id == o.webhook_id && assignments == o.assignments && randomize_on_entry == o.randomize_on_entry && branches == o.branches && expiration == o.expiration end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/onesignal/models/journey_node.rb', line 393 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OneSignal.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
464 465 466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/onesignal/models/journey_node.rb', line 464 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/onesignal/models/journey_node.rb', line 369 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
349 350 351 |
# File 'lib/onesignal/models/journey_node.rb', line 349 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
355 356 357 |
# File 'lib/onesignal/models/journey_node.rb', line 355 def hash [id, kind, client_node_id, annotation, duration_seconds, relative_to, windows, time_zone, use_user_time_zone, template_id, iam_id, user_ttl_seconds, webhook_id, assignments, randomize_on_entry, branches, expiration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/onesignal/models/journey_node.rb', line 244 def list_invalid_properties invalid_properties = Array.new if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if !@duration_seconds.nil? && @duration_seconds > 31556952 invalid_properties.push('invalid value for "duration_seconds", must be smaller than or equal to 31556952.') end if !@duration_seconds.nil? && @duration_seconds < 60 invalid_properties.push('invalid value for "duration_seconds", must be greater than or equal to 60.') end if !@user_ttl_seconds.nil? && @user_ttl_seconds < 1 invalid_properties.push('invalid value for "user_ttl_seconds", must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
440 441 442 |
# File 'lib/onesignal/models/journey_node.rb', line 440 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/onesignal/models/journey_node.rb', line 446 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
434 435 436 |
# File 'lib/onesignal/models/journey_node.rb', line 434 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/onesignal/models/journey_node.rb', line 267 def valid? return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["wait", "time_window", "send_push", "send_email", "send_sms", "send_iam", "send_webhook", "tag", "split_range", "yes_no", "wait_until"]) return false unless kind_validator.valid?(@kind) return false if !@duration_seconds.nil? && @duration_seconds > 31556952 return false if !@duration_seconds.nil? && @duration_seconds < 60 relative_to_validator = EnumAttributeValidator.new('String', ["schedule_in_timezone", "last_active_time"]) return false unless relative_to_validator.valid?(@relative_to) return false if !@user_ttl_seconds.nil? && @user_ttl_seconds < 1 true end |