Class: OneSignal::LanguageStringMap
- Inherits:
-
Object
- Object
- OneSignal::LanguageStringMap
- Defined in:
- lib/onesignal/models/language_string_map.rb
Instance Attribute Summary collapse
-
#ar ⇒ Object
Text in Arabic.
-
#bg ⇒ Object
Text in Bulgarian.
-
#bs ⇒ Object
Text in Bosnian.
-
#ca ⇒ Object
Text in Catalan.
-
#cs ⇒ Object
Text in Czech.
-
#da ⇒ Object
Text in Danish.
-
#de ⇒ Object
Text in German.
-
#el ⇒ Object
Text in Greek.
-
#en ⇒ Object
Text in English.
-
#es ⇒ Object
Text in Spanish.
-
#et ⇒ Object
Text in Estonian.
-
#fa ⇒ Object
Text in Persian.
-
#fi ⇒ Object
Text in Finnish.
-
#fr ⇒ Object
Text in French.
-
#he ⇒ Object
Text in Hebrew.
-
#hi ⇒ Object
Text in Hindi.
-
#hr ⇒ Object
Text in Croatian.
-
#hu ⇒ Object
Text in Hungarian.
-
#id ⇒ Object
Text in Indonesian.
-
#it ⇒ Object
Text in Italian.
-
#ja ⇒ Object
Text in Japanese.
-
#ka ⇒ Object
Text in Georgian.
-
#ko ⇒ Object
Text in Korean.
-
#lt ⇒ Object
Text in Lithuanian.
-
#lv ⇒ Object
Text in Latvian.
-
#ms ⇒ Object
Text in Malay.
-
#nb ⇒ Object
Text in Norwegian.
-
#nl ⇒ Object
Text in Dutch.
-
#pa ⇒ Object
Text in Punjabi.
-
#pl ⇒ Object
Text in Polish.
-
#pt ⇒ Object
Text in Portugese.
-
#ro ⇒ Object
Text in Romanian.
-
#ru ⇒ Object
Text in Russian.
-
#sk ⇒ Object
Text in Slovak.
-
#sr ⇒ Object
Text in Serbian.
-
#sv ⇒ Object
Text in Swedish.
-
#th ⇒ Object
Text in Thai.
-
#tr ⇒ Object
Text in Turkish.
-
#uk ⇒ Object
Text in Ukrainian.
-
#vi ⇒ Object
Text in Vietnamese.
-
#zh ⇒ Object
Alias for zh-Hans.
-
#zh_hans ⇒ Object
Text in Chinese (Simplified).
-
#zh_hant ⇒ Object
Text in Chinese (Traditional).
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LanguageStringMap
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LanguageStringMap
Initializes the object
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/onesignal/models/language_string_map.rb', line 257 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneSignal::LanguageStringMap` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneSignal::LanguageStringMap`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'en') self.en = attributes[:'en'] end if attributes.key?(:'ar') self.ar = attributes[:'ar'] end if attributes.key?(:'bs') self.bs = attributes[:'bs'] end if attributes.key?(:'bg') self.bg = attributes[:'bg'] end if attributes.key?(:'ca') self.ca = attributes[:'ca'] end if attributes.key?(:'zh_hans') self.zh_hans = attributes[:'zh_hans'] end if attributes.key?(:'zh_hant') self.zh_hant = attributes[:'zh_hant'] end if attributes.key?(:'zh') self.zh = attributes[:'zh'] end if attributes.key?(:'hr') self.hr = attributes[:'hr'] end if attributes.key?(:'cs') self.cs = attributes[:'cs'] end if attributes.key?(:'da') self.da = attributes[:'da'] end if attributes.key?(:'nl') self.nl = attributes[:'nl'] end if attributes.key?(:'et') self.et = attributes[:'et'] end if attributes.key?(:'fi') self.fi = attributes[:'fi'] end if attributes.key?(:'fr') self.fr = attributes[:'fr'] end if attributes.key?(:'ka') self.ka = attributes[:'ka'] end if attributes.key?(:'de') self.de = attributes[:'de'] end if attributes.key?(:'el') self.el = attributes[:'el'] end if attributes.key?(:'hi') self.hi = attributes[:'hi'] end if attributes.key?(:'he') self.he = attributes[:'he'] end if attributes.key?(:'hu') self.hu = attributes[:'hu'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'it') self.it = attributes[:'it'] end if attributes.key?(:'ja') self.ja = attributes[:'ja'] end if attributes.key?(:'ko') self.ko = attributes[:'ko'] end if attributes.key?(:'lv') self.lv = attributes[:'lv'] end if attributes.key?(:'lt') self.lt = attributes[:'lt'] end if attributes.key?(:'ms') self.ms = attributes[:'ms'] end if attributes.key?(:'nb') self.nb = attributes[:'nb'] end if attributes.key?(:'pl') self.pl = attributes[:'pl'] end if attributes.key?(:'fa') self.fa = attributes[:'fa'] end if attributes.key?(:'pt') self.pt = attributes[:'pt'] end if attributes.key?(:'pa') self.pa = attributes[:'pa'] end if attributes.key?(:'ro') self.ro = attributes[:'ro'] end if attributes.key?(:'ru') self.ru = attributes[:'ru'] end if attributes.key?(:'sr') self.sr = attributes[:'sr'] end if attributes.key?(:'sk') self.sk = attributes[:'sk'] end if attributes.key?(:'es') self.es = attributes[:'es'] end if attributes.key?(:'sv') self.sv = attributes[:'sv'] end if attributes.key?(:'th') self.th = attributes[:'th'] end if attributes.key?(:'tr') self.tr = attributes[:'tr'] end if attributes.key?(:'uk') self.uk = attributes[:'uk'] end if attributes.key?(:'vi') self.vi = attributes[:'vi'] end end |
Instance Attribute Details
#ar ⇒ Object
Text in Arabic.
21 22 23 |
# File 'lib/onesignal/models/language_string_map.rb', line 21 def ar @ar end |
#bg ⇒ Object
Text in Bulgarian.
27 28 29 |
# File 'lib/onesignal/models/language_string_map.rb', line 27 def bg @bg end |
#bs ⇒ Object
Text in Bosnian.
24 25 26 |
# File 'lib/onesignal/models/language_string_map.rb', line 24 def bs @bs end |
#ca ⇒ Object
Text in Catalan.
30 31 32 |
# File 'lib/onesignal/models/language_string_map.rb', line 30 def ca @ca end |
#cs ⇒ Object
Text in Czech.
45 46 47 |
# File 'lib/onesignal/models/language_string_map.rb', line 45 def cs @cs end |
#da ⇒ Object
Text in Danish.
48 49 50 |
# File 'lib/onesignal/models/language_string_map.rb', line 48 def da @da end |
#de ⇒ Object
Text in German.
66 67 68 |
# File 'lib/onesignal/models/language_string_map.rb', line 66 def de @de end |
#el ⇒ Object
Text in Greek.
69 70 71 |
# File 'lib/onesignal/models/language_string_map.rb', line 69 def el @el end |
#en ⇒ Object
Text in English. Will be used as a fallback
18 19 20 |
# File 'lib/onesignal/models/language_string_map.rb', line 18 def en @en end |
#es ⇒ Object
Text in Spanish.
129 130 131 |
# File 'lib/onesignal/models/language_string_map.rb', line 129 def es @es end |
#et ⇒ Object
Text in Estonian.
54 55 56 |
# File 'lib/onesignal/models/language_string_map.rb', line 54 def et @et end |
#fa ⇒ Object
Text in Persian.
108 109 110 |
# File 'lib/onesignal/models/language_string_map.rb', line 108 def fa @fa end |
#fi ⇒ Object
Text in Finnish.
57 58 59 |
# File 'lib/onesignal/models/language_string_map.rb', line 57 def fi @fi end |
#fr ⇒ Object
Text in French.
60 61 62 |
# File 'lib/onesignal/models/language_string_map.rb', line 60 def fr @fr end |
#he ⇒ Object
Text in Hebrew.
75 76 77 |
# File 'lib/onesignal/models/language_string_map.rb', line 75 def he @he end |
#hi ⇒ Object
Text in Hindi.
72 73 74 |
# File 'lib/onesignal/models/language_string_map.rb', line 72 def hi @hi end |
#hr ⇒ Object
Text in Croatian.
42 43 44 |
# File 'lib/onesignal/models/language_string_map.rb', line 42 def hr @hr end |
#hu ⇒ Object
Text in Hungarian.
78 79 80 |
# File 'lib/onesignal/models/language_string_map.rb', line 78 def hu @hu end |
#id ⇒ Object
Text in Indonesian.
81 82 83 |
# File 'lib/onesignal/models/language_string_map.rb', line 81 def id @id end |
#it ⇒ Object
Text in Italian.
84 85 86 |
# File 'lib/onesignal/models/language_string_map.rb', line 84 def it @it end |
#ja ⇒ Object
Text in Japanese.
87 88 89 |
# File 'lib/onesignal/models/language_string_map.rb', line 87 def ja @ja end |
#ka ⇒ Object
Text in Georgian.
63 64 65 |
# File 'lib/onesignal/models/language_string_map.rb', line 63 def ka @ka end |
#ko ⇒ Object
Text in Korean.
90 91 92 |
# File 'lib/onesignal/models/language_string_map.rb', line 90 def ko @ko end |
#lt ⇒ Object
Text in Lithuanian.
96 97 98 |
# File 'lib/onesignal/models/language_string_map.rb', line 96 def lt @lt end |
#lv ⇒ Object
Text in Latvian.
93 94 95 |
# File 'lib/onesignal/models/language_string_map.rb', line 93 def lv @lv end |
#ms ⇒ Object
Text in Malay.
99 100 101 |
# File 'lib/onesignal/models/language_string_map.rb', line 99 def ms @ms end |
#nb ⇒ Object
Text in Norwegian.
102 103 104 |
# File 'lib/onesignal/models/language_string_map.rb', line 102 def nb @nb end |
#nl ⇒ Object
Text in Dutch.
51 52 53 |
# File 'lib/onesignal/models/language_string_map.rb', line 51 def nl @nl end |
#pa ⇒ Object
Text in Punjabi.
114 115 116 |
# File 'lib/onesignal/models/language_string_map.rb', line 114 def pa @pa end |
#pl ⇒ Object
Text in Polish.
105 106 107 |
# File 'lib/onesignal/models/language_string_map.rb', line 105 def pl @pl end |
#pt ⇒ Object
Text in Portugese.
111 112 113 |
# File 'lib/onesignal/models/language_string_map.rb', line 111 def pt @pt end |
#ro ⇒ Object
Text in Romanian.
117 118 119 |
# File 'lib/onesignal/models/language_string_map.rb', line 117 def ro @ro end |
#ru ⇒ Object
Text in Russian.
120 121 122 |
# File 'lib/onesignal/models/language_string_map.rb', line 120 def ru @ru end |
#sk ⇒ Object
Text in Slovak.
126 127 128 |
# File 'lib/onesignal/models/language_string_map.rb', line 126 def sk @sk end |
#sr ⇒ Object
Text in Serbian.
123 124 125 |
# File 'lib/onesignal/models/language_string_map.rb', line 123 def sr @sr end |
#sv ⇒ Object
Text in Swedish.
132 133 134 |
# File 'lib/onesignal/models/language_string_map.rb', line 132 def sv @sv end |
#th ⇒ Object
Text in Thai.
135 136 137 |
# File 'lib/onesignal/models/language_string_map.rb', line 135 def th @th end |
#tr ⇒ Object
Text in Turkish.
138 139 140 |
# File 'lib/onesignal/models/language_string_map.rb', line 138 def tr @tr end |
#uk ⇒ Object
Text in Ukrainian.
141 142 143 |
# File 'lib/onesignal/models/language_string_map.rb', line 141 def uk @uk end |
#vi ⇒ Object
Text in Vietnamese.
144 145 146 |
# File 'lib/onesignal/models/language_string_map.rb', line 144 def vi @vi end |
#zh ⇒ Object
Alias for zh-Hans.
39 40 41 |
# File 'lib/onesignal/models/language_string_map.rb', line 39 def zh @zh end |
#zh_hans ⇒ Object
Text in Chinese (Simplified).
33 34 35 |
# File 'lib/onesignal/models/language_string_map.rb', line 33 def zh_hans @zh_hans end |
#zh_hant ⇒ Object
Text in Chinese (Traditional).
36 37 38 |
# File 'lib/onesignal/models/language_string_map.rb', line 36 def zh_hant @zh_hant end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
196 197 198 |
# File 'lib/onesignal/models/language_string_map.rb', line 196 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/onesignal/models/language_string_map.rb', line 147 def self.attribute_map { :'en' => :'en', :'ar' => :'ar', :'bs' => :'bs', :'bg' => :'bg', :'ca' => :'ca', :'zh_hans' => :'zh-Hans', :'zh_hant' => :'zh-Hant', :'zh' => :'zh', :'hr' => :'hr', :'cs' => :'cs', :'da' => :'da', :'nl' => :'nl', :'et' => :'et', :'fi' => :'fi', :'fr' => :'fr', :'ka' => :'ka', :'de' => :'de', :'el' => :'el', :'hi' => :'hi', :'he' => :'he', :'hu' => :'hu', :'id' => :'id', :'it' => :'it', :'ja' => :'ja', :'ko' => :'ko', :'lv' => :'lv', :'lt' => :'lt', :'ms' => :'ms', :'nb' => :'nb', :'pl' => :'pl', :'fa' => :'fa', :'pt' => :'pt', :'pa' => :'pa', :'ro' => :'ro', :'ru' => :'ru', :'sr' => :'sr', :'sk' => :'sk', :'es' => :'es', :'sv' => :'sv', :'th' => :'th', :'tr' => :'tr', :'uk' => :'uk', :'vi' => :'vi' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
521 522 523 |
# File 'lib/onesignal/models/language_string_map.rb', line 521 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
250 251 252 253 |
# File 'lib/onesignal/models/language_string_map.rb', line 250 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/onesignal/models/language_string_map.rb', line 201 def self.openapi_types { :'en' => :'String', :'ar' => :'String', :'bs' => :'String', :'bg' => :'String', :'ca' => :'String', :'zh_hans' => :'String', :'zh_hant' => :'String', :'zh' => :'String', :'hr' => :'String', :'cs' => :'String', :'da' => :'String', :'nl' => :'String', :'et' => :'String', :'fi' => :'String', :'fr' => :'String', :'ka' => :'String', :'de' => :'String', :'el' => :'String', :'hi' => :'String', :'he' => :'String', :'hu' => :'String', :'id' => :'String', :'it' => :'String', :'ja' => :'String', :'ko' => :'String', :'lv' => :'String', :'lt' => :'String', :'ms' => :'String', :'nb' => :'String', :'pl' => :'String', :'fa' => :'String', :'pt' => :'String', :'pa' => :'String', :'ro' => :'String', :'ru' => :'String', :'sr' => :'String', :'sk' => :'String', :'es' => :'String', :'sv' => :'String', :'th' => :'String', :'tr' => :'String', :'uk' => :'String', :'vi' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/onesignal/models/language_string_map.rb', line 458 def ==(o) return true if self.equal?(o) self.class == o.class && en == o.en && ar == o.ar && bs == o.bs && bg == o.bg && ca == o.ca && zh_hans == o.zh_hans && zh_hant == o.zh_hant && zh == o.zh && hr == o.hr && cs == o.cs && da == o.da && nl == o.nl && et == o.et && fi == o.fi && fr == o.fr && ka == o.ka && de == o.de && el == o.el && hi == o.hi && he == o.he && hu == o.hu && id == o.id && it == o.it && ja == o.ja && ko == o.ko && lv == o.lv && lt == o.lt && ms == o.ms && nb == o.nb && pl == o.pl && fa == o.fa && pt == o.pt && pa == o.pa && ro == o.ro && ru == o.ru && sr == o.sr && sk == o.sk && es == o.es && sv == o.sv && th == o.th && tr == o.tr && uk == o.uk && vi == o.vi end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/onesignal/models/language_string_map.rb', line 552 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OneSignal.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
623 624 625 626 627 628 629 630 631 632 633 634 635 |
# File 'lib/onesignal/models/language_string_map.rb', line 623 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/onesignal/models/language_string_map.rb', line 528 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
508 509 510 |
# File 'lib/onesignal/models/language_string_map.rb', line 508 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
514 515 516 |
# File 'lib/onesignal/models/language_string_map.rb', line 514 def hash [en, ar, bs, bg, ca, zh_hans, zh_hant, zh, hr, cs, da, nl, et, fi, fr, ka, de, el, hi, he, hu, id, it, ja, ko, lv, lt, ms, nb, pl, fa, pt, pa, ro, ru, sr, sk, es, sv, th, tr, uk, vi].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
445 446 447 448 |
# File 'lib/onesignal/models/language_string_map.rb', line 445 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
599 600 601 |
# File 'lib/onesignal/models/language_string_map.rb', line 599 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/onesignal/models/language_string_map.rb', line 605 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
593 594 595 |
# File 'lib/onesignal/models/language_string_map.rb', line 593 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
452 453 454 |
# File 'lib/onesignal/models/language_string_map.rb', line 452 def valid? true end |