Class: OneSignal::Subscription

Inherits:
Object
  • Object
show all
Defined in:
lib/onesignal/models/subscription.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Subscription

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/onesignal/models/subscription.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OneSignal::Subscription` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OneSignal::Subscription`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'notification_types')
    self.notification_types = attributes[:'notification_types']
  end

  if attributes.key?(:'session_time')
    self.session_time = attributes[:'session_time']
  end

  if attributes.key?(:'session_count')
    self.session_count = attributes[:'session_count']
  end

  if attributes.key?(:'sdk')
    self.sdk = attributes[:'sdk']
  end

  if attributes.key?(:'device_model')
    self.device_model = attributes[:'device_model']
  end

  if attributes.key?(:'device_os')
    self.device_os = attributes[:'device_os']
  end

  if attributes.key?(:'rooted')
    self.rooted = attributes[:'rooted']
  end

  if attributes.key?(:'test_type')
    self.test_type = attributes[:'test_type']
  end

  if attributes.key?(:'app_version')
    self.app_version = attributes[:'app_version']
  end

  if attributes.key?(:'net_type')
    self.net_type = attributes[:'net_type']
  end

  if attributes.key?(:'carrier')
    self.carrier = attributes[:'carrier']
  end

  if attributes.key?(:'web_auth')
    self.web_auth = attributes[:'web_auth']
  end

  if attributes.key?(:'web_p256')
    self.web_p256 = attributes[:'web_p256']
  end
end

Instance Attribute Details

#app_versionObject

Returns the value of attribute app_version.



41
42
43
# File 'lib/onesignal/models/subscription.rb', line 41

def app_version
  @app_version
end

#carrierObject

Returns the value of attribute carrier.



45
46
47
# File 'lib/onesignal/models/subscription.rb', line 45

def carrier
  @carrier
end

#device_modelObject

Returns the value of attribute device_model.



33
34
35
# File 'lib/onesignal/models/subscription.rb', line 33

def device_model
  @device_model
end

#device_osObject

Returns the value of attribute device_os.



35
36
37
# File 'lib/onesignal/models/subscription.rb', line 35

def device_os
  @device_os
end

#enabledObject

Returns the value of attribute enabled.



23
24
25
# File 'lib/onesignal/models/subscription.rb', line 23

def enabled
  @enabled
end

#idObject

Returns the value of attribute id.



17
18
19
# File 'lib/onesignal/models/subscription.rb', line 17

def id
  @id
end

#net_typeObject

Returns the value of attribute net_type.



43
44
45
# File 'lib/onesignal/models/subscription.rb', line 43

def net_type
  @net_type
end

#notification_typesObject

Returns the value of attribute notification_types.



25
26
27
# File 'lib/onesignal/models/subscription.rb', line 25

def notification_types
  @notification_types
end

#rootedObject

Returns the value of attribute rooted.



37
38
39
# File 'lib/onesignal/models/subscription.rb', line 37

def rooted
  @rooted
end

#sdkObject

Returns the value of attribute sdk.



31
32
33
# File 'lib/onesignal/models/subscription.rb', line 31

def sdk
  @sdk
end

#session_countObject

Returns the value of attribute session_count.



29
30
31
# File 'lib/onesignal/models/subscription.rb', line 29

def session_count
  @session_count
end

#session_timeObject

Returns the value of attribute session_time.



27
28
29
# File 'lib/onesignal/models/subscription.rb', line 27

def session_time
  @session_time
end

#test_typeObject

Returns the value of attribute test_type.



39
40
41
# File 'lib/onesignal/models/subscription.rb', line 39

def test_type
  @test_type
end

#tokenObject

Returns the value of attribute token.



21
22
23
# File 'lib/onesignal/models/subscription.rb', line 21

def token
  @token
end

#typeObject

Returns the value of attribute type.



19
20
21
# File 'lib/onesignal/models/subscription.rb', line 19

def type
  @type
end

#web_authObject

Returns the value of attribute web_auth.



47
48
49
# File 'lib/onesignal/models/subscription.rb', line 47

def web_auth
  @web_auth
end

#web_p256Object

Returns the value of attribute web_p256.



49
50
51
# File 'lib/onesignal/models/subscription.rb', line 49

def web_p256
  @web_p256
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/onesignal/models/subscription.rb', line 97

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/onesignal/models/subscription.rb', line 74

def self.attribute_map
  {
    :'id' => :'id',
    :'type' => :'type',
    :'token' => :'token',
    :'enabled' => :'enabled',
    :'notification_types' => :'notification_types',
    :'session_time' => :'session_time',
    :'session_count' => :'session_count',
    :'sdk' => :'sdk',
    :'device_model' => :'device_model',
    :'device_os' => :'device_os',
    :'rooted' => :'rooted',
    :'test_type' => :'test_type',
    :'app_version' => :'app_version',
    :'net_type' => :'net_type',
    :'carrier' => :'carrier',
    :'web_auth' => :'web_auth',
    :'web_p256' => :'web_p256'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
# File 'lib/onesignal/models/subscription.rb', line 278

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



125
126
127
128
# File 'lib/onesignal/models/subscription.rb', line 125

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/onesignal/models/subscription.rb', line 102

def self.openapi_types
  {
    :'id' => :'String',
    :'type' => :'String',
    :'token' => :'String',
    :'enabled' => :'Boolean',
    :'notification_types' => :'Integer',
    :'session_time' => :'Integer',
    :'session_count' => :'Integer',
    :'sdk' => :'String',
    :'device_model' => :'String',
    :'device_os' => :'String',
    :'rooted' => :'Boolean',
    :'test_type' => :'Integer',
    :'app_version' => :'String',
    :'net_type' => :'Integer',
    :'carrier' => :'String',
    :'web_auth' => :'String',
    :'web_p256' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/onesignal/models/subscription.rb', line 241

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      type == o.type &&
      token == o.token &&
      enabled == o.enabled &&
      notification_types == o.notification_types &&
      session_time == o.session_time &&
      session_count == o.session_count &&
      sdk == o.sdk &&
      device_model == o.device_model &&
      device_os == o.device_os &&
      rooted == o.rooted &&
      test_type == o.test_type &&
      app_version == o.app_version &&
      net_type == o.net_type &&
      carrier == o.carrier &&
      web_auth == o.web_auth &&
      web_p256 == o.web_p256
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/onesignal/models/subscription.rb', line 309

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = OneSignal.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/onesignal/models/subscription.rb', line 380

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/onesignal/models/subscription.rb', line 285

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/onesignal/models/subscription.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/onesignal/models/subscription.rb', line 271

def hash
  [id, type, token, enabled, notification_types, session_time, session_count, sdk, device_model, device_os, rooted, test_type, app_version, net_type, carrier, web_auth, web_p256].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



216
217
218
219
# File 'lib/onesignal/models/subscription.rb', line 216

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
# File 'lib/onesignal/models/subscription.rb', line 356

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/onesignal/models/subscription.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



350
351
352
# File 'lib/onesignal/models/subscription.rb', line 350

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
# File 'lib/onesignal/models/subscription.rb', line 223

def valid?
  type_validator = EnumAttributeValidator.new('String', ["iOSPush", "AndroidPush", "FireOSPush", "ChromeExtensionPush", "ChromePush", "WindowsPush", "SafariLegacyPush", "FirefoxPush", "macOSPush", "HuaweiPush", "SafariPush", "Email", "SMS"])
  return false unless type_validator.valid?(@type)
  true
end