Class: OneSignal::NotificationWithMetaAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/onesignal/models/notification_with_meta_all_of.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NotificationWithMetaAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OneSignal::NotificationWithMetaAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OneSignal::NotificationWithMetaAllOf`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'remaining')
    self.remaining = attributes[:'remaining']
  end

  if attributes.key?(:'successful')
    self.successful = attributes[:'successful']
  end

  if attributes.key?(:'failed')
    self.failed = attributes[:'failed']
  end

  if attributes.key?(:'errored')
    self.errored = attributes[:'errored']
  end

  if attributes.key?(:'converted')
    self.converted = attributes[:'converted']
  end

  if attributes.key?(:'queued_at')
    self.queued_at = attributes[:'queued_at']
  end

  if attributes.key?(:'send_after')
    self.send_after = attributes[:'send_after']
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  end

  if attributes.key?(:'platform_delivery_stats')
    self.platform_delivery_stats = attributes[:'platform_delivery_stats']
  end

  if attributes.key?(:'received')
    self.received = attributes[:'received']
  end

  if attributes.key?(:'throttle_rate_per_minute')
    self.throttle_rate_per_minute = attributes[:'throttle_rate_per_minute']
  end

  if attributes.key?(:'canceled')
    self.canceled = attributes[:'canceled']
  end

  if attributes.key?(:'email_bcc')
    if (value = attributes[:'email_bcc']).is_a?(Array)
      self.email_bcc = value
    end
  end

  if attributes.key?(:'bcc_sent')
    self.bcc_sent = attributes[:'bcc_sent']
  end
end

Instance Attribute Details

#bcc_sentObject

Number of BCC copies successfully sent for this notification.



57
58
59
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 57

def bcc_sent
  @bcc_sent
end

#canceledObject

Indicates whether the notification was canceled before it could be sent.



51
52
53
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 51

def canceled
  @canceled
end

#completed_atObject

Unix timestamp indicating when notification delivery completed. The delivery duration from start to finish can be calculated with completed_at - send_after.



40
41
42
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 40

def completed_at
  @completed_at
end

#convertedObject

Number of users who have clicked / tapped on your notification.



31
32
33
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 31

def converted
  @converted
end

#email_bccObject

BCC recipients that were set on this email notification.



54
55
56
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 54

def email_bcc
  @email_bcc
end

#erroredObject

Number of notifications that could not be delivered due to an error. You can find more information by viewing the notification in the dashboard.



28
29
30
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 28

def errored
  @errored
end

#failedObject

Number of notifications that could not be delivered due to those devices being unsubscribed.



25
26
27
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 25

def failed
  @failed
end

#platform_delivery_statsObject

Returns the value of attribute platform_delivery_stats.



42
43
44
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 42

def platform_delivery_stats
  @platform_delivery_stats
end

#queued_atObject

Unix timestamp indicating when the notification was created.



34
35
36
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 34

def queued_at
  @queued_at
end

#receivedObject

Confirmed Deliveries number of devices that received the push notification. Paid Feature Only. Free accounts will see 0.



45
46
47
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 45

def received
  @received
end

#remainingObject

Number of notifications that have not been sent out yet. This can mean either our system is still processing the notification or you have delayed options set.



19
20
21
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 19

def remaining
  @remaining
end

#send_afterObject

Unix timestamp indicating when notification delivery should begin.



37
38
39
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 37

def send_after
  @send_after
end

#successfulObject

Number of notifications that were successfully delivered.



22
23
24
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 22

def successful
  @successful
end

#throttle_rate_per_minuteObject

number of push notifications sent per minute. Paid Feature Only. If throttling is not enabled for the app or the notification, and for free accounts, null is returned. Refer to Throttling for more details.



48
49
50
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 48

def throttle_rate_per_minute
  @throttle_rate_per_minute
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 60

def self.attribute_map
  {
    :'remaining' => :'remaining',
    :'successful' => :'successful',
    :'failed' => :'failed',
    :'errored' => :'errored',
    :'converted' => :'converted',
    :'queued_at' => :'queued_at',
    :'send_after' => :'send_after',
    :'completed_at' => :'completed_at',
    :'platform_delivery_stats' => :'platform_delivery_stats',
    :'received' => :'received',
    :'throttle_rate_per_minute' => :'throttle_rate_per_minute',
    :'canceled' => :'canceled',
    :'email_bcc' => :'email_bcc',
    :'bcc_sent' => :'bcc_sent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 239

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
109
110
111
112
113
114
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 105

def self.openapi_nullable
  Set.new([
    :'send_after',
    :'completed_at',
    :'received',
    :'throttle_rate_per_minute',
    :'email_bcc',
    :'bcc_sent'
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 85

def self.openapi_types
  {
    :'remaining' => :'Integer',
    :'successful' => :'Integer',
    :'failed' => :'Integer',
    :'errored' => :'Integer',
    :'converted' => :'Integer',
    :'queued_at' => :'Integer',
    :'send_after' => :'Integer',
    :'completed_at' => :'Integer',
    :'platform_delivery_stats' => :'PlatformDeliveryData',
    :'received' => :'Integer',
    :'throttle_rate_per_minute' => :'Integer',
    :'canceled' => :'Boolean',
    :'email_bcc' => :'Array<String>',
    :'bcc_sent' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 205

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      remaining == o.remaining &&
      successful == o.successful &&
      failed == o.failed &&
      errored == o.errored &&
      converted == o.converted &&
      queued_at == o.queued_at &&
      send_after == o.send_after &&
      completed_at == o.completed_at &&
      platform_delivery_stats == o.platform_delivery_stats &&
      received == o.received &&
      throttle_rate_per_minute == o.throttle_rate_per_minute &&
      canceled == o.canceled &&
      email_bcc == o.email_bcc &&
      bcc_sent == o.bcc_sent
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 270

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = OneSignal.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 341

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 246

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 232

def hash
  [remaining, successful, failed, errored, converted, queued_at, send_after, completed_at, platform_delivery_stats, received, throttle_rate_per_minute, canceled, email_bcc, bcc_sent].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 192

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 317

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



311
312
313
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 311

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



199
200
201
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 199

def valid?
  true
end