Class: OneSignal::NotificationWithMetaAllOf
- Inherits:
-
Object
- Object
- OneSignal::NotificationWithMetaAllOf
- Defined in:
- lib/onesignal/models/notification_with_meta_all_of.rb
Instance Attribute Summary collapse
-
#bcc_sent ⇒ Object
Number of BCC copies successfully sent for this notification.
-
#canceled ⇒ Object
Indicates whether the notification was canceled before it could be sent.
-
#completed_at ⇒ Object
Unix timestamp indicating when notification delivery completed.
-
#converted ⇒ Object
Number of users who have clicked / tapped on your notification.
-
#email_bcc ⇒ Object
BCC recipients that were set on this email notification.
-
#email_warm_up ⇒ Object
Returns the value of attribute email_warm_up.
-
#errored ⇒ Object
Number of notifications that could not be delivered due to an error.
-
#failed ⇒ Object
Number of notifications that could not be delivered due to those devices being unsubscribed.
-
#platform_delivery_stats ⇒ Object
Returns the value of attribute platform_delivery_stats.
-
#queued_at ⇒ Object
Unix timestamp indicating when the notification was created.
-
#received ⇒ Object
Confirmed Deliveries number of devices that received the push notification.
-
#remaining ⇒ Object
Number of notifications that have not been sent out yet.
-
#send_after ⇒ Object
Unix timestamp indicating when notification delivery should begin.
-
#successful ⇒ Object
Number of notifications that were successfully delivered.
-
#throttle_rate_per_minute ⇒ Object
number of push notifications sent per minute.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NotificationWithMetaAllOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ NotificationWithMetaAllOf
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneSignal::NotificationWithMetaAllOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneSignal::NotificationWithMetaAllOf`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'remaining') self.remaining = attributes[:'remaining'] end if attributes.key?(:'successful') self.successful = attributes[:'successful'] end if attributes.key?(:'failed') self.failed = attributes[:'failed'] end if attributes.key?(:'errored') self.errored = attributes[:'errored'] end if attributes.key?(:'converted') self.converted = attributes[:'converted'] end if attributes.key?(:'queued_at') self.queued_at = attributes[:'queued_at'] end if attributes.key?(:'send_after') self.send_after = attributes[:'send_after'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'platform_delivery_stats') self.platform_delivery_stats = attributes[:'platform_delivery_stats'] end if attributes.key?(:'received') self.received = attributes[:'received'] end if attributes.key?(:'throttle_rate_per_minute') self.throttle_rate_per_minute = attributes[:'throttle_rate_per_minute'] end if attributes.key?(:'canceled') self.canceled = attributes[:'canceled'] end if attributes.key?(:'email_bcc') if (value = attributes[:'email_bcc']).is_a?(Array) self.email_bcc = value end end if attributes.key?(:'bcc_sent') self.bcc_sent = attributes[:'bcc_sent'] end if attributes.key?(:'email_warm_up') self.email_warm_up = attributes[:'email_warm_up'] end end |
Instance Attribute Details
#bcc_sent ⇒ Object
Number of BCC copies successfully sent for this notification.
56 57 58 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 56 def bcc_sent @bcc_sent end |
#canceled ⇒ Object
Indicates whether the notification was canceled before it could be sent.
50 51 52 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 50 def canceled @canceled end |
#completed_at ⇒ Object
Unix timestamp indicating when notification delivery completed. The delivery duration from start to finish can be calculated with completed_at - send_after.
39 40 41 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 39 def completed_at @completed_at end |
#converted ⇒ Object
Number of users who have clicked / tapped on your notification.
30 31 32 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 30 def converted @converted end |
#email_bcc ⇒ Object
BCC recipients that were set on this email notification.
53 54 55 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 53 def email_bcc @email_bcc end |
#email_warm_up ⇒ Object
Returns the value of attribute email_warm_up.
58 59 60 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 58 def email_warm_up @email_warm_up end |
#errored ⇒ Object
Number of notifications that could not be delivered due to an error. You can find more information by viewing the notification in the dashboard.
27 28 29 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 27 def errored @errored end |
#failed ⇒ Object
Number of notifications that could not be delivered due to those devices being unsubscribed.
24 25 26 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 24 def failed @failed end |
#platform_delivery_stats ⇒ Object
Returns the value of attribute platform_delivery_stats.
41 42 43 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 41 def platform_delivery_stats @platform_delivery_stats end |
#queued_at ⇒ Object
Unix timestamp indicating when the notification was created.
33 34 35 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 33 def queued_at @queued_at end |
#received ⇒ Object
Confirmed Deliveries number of devices that received the push notification. Paid Feature Only. Free accounts will see 0.
44 45 46 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 44 def received @received end |
#remaining ⇒ Object
Number of notifications that have not been sent out yet. This can mean either our system is still processing the notification or you have delayed options set.
18 19 20 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 18 def remaining @remaining end |
#send_after ⇒ Object
Unix timestamp indicating when notification delivery should begin.
36 37 38 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 36 def send_after @send_after end |
#successful ⇒ Object
Number of notifications that were successfully delivered.
21 22 23 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 21 def successful @successful end |
#throttle_rate_per_minute ⇒ Object
number of push notifications sent per minute. Paid Feature Only. If throttling is not enabled for the app or the notification, and for free accounts, null is returned. Refer to Throttling for more details.
47 48 49 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 47 def throttle_rate_per_minute @throttle_rate_per_minute end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 82 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 61 def self.attribute_map { :'remaining' => :'remaining', :'successful' => :'successful', :'failed' => :'failed', :'errored' => :'errored', :'converted' => :'converted', :'queued_at' => :'queued_at', :'send_after' => :'send_after', :'completed_at' => :'completed_at', :'platform_delivery_stats' => :'platform_delivery_stats', :'received' => :'received', :'throttle_rate_per_minute' => :'throttle_rate_per_minute', :'canceled' => :'canceled', :'email_bcc' => :'email_bcc', :'bcc_sent' => :'bcc_sent', :'email_warm_up' => :'email_warm_up' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 247 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 112 113 114 115 116 117 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 108 def self.openapi_nullable Set.new([ :'send_after', :'completed_at', :'received', :'throttle_rate_per_minute', :'email_bcc', :'bcc_sent', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 87 def self.openapi_types { :'remaining' => :'Integer', :'successful' => :'Integer', :'failed' => :'Integer', :'errored' => :'Integer', :'converted' => :'Integer', :'queued_at' => :'Integer', :'send_after' => :'Integer', :'completed_at' => :'Integer', :'platform_delivery_stats' => :'PlatformDeliveryData', :'received' => :'Integer', :'throttle_rate_per_minute' => :'Integer', :'canceled' => :'Boolean', :'email_bcc' => :'Array<String>', :'bcc_sent' => :'Integer', :'email_warm_up' => :'EmailWarmUp' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && remaining == o.remaining && successful == o.successful && failed == o.failed && errored == o.errored && converted == o.converted && queued_at == o.queued_at && send_after == o.send_after && completed_at == o.completed_at && platform_delivery_stats == o.platform_delivery_stats && received == o.received && throttle_rate_per_minute == o.throttle_rate_per_minute && canceled == o.canceled && email_bcc == o.email_bcc && bcc_sent == o.bcc_sent && email_warm_up == o.email_warm_up end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 278 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OneSignal.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 349 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 254 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 240 def hash [remaining, successful, failed, errored, converted, queued_at, send_after, completed_at, platform_delivery_stats, received, throttle_rate_per_minute, canceled, email_bcc, bcc_sent, email_warm_up].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
199 200 201 202 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 199 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
325 326 327 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 325 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
319 320 321 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 319 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 |
# File 'lib/onesignal/models/notification_with_meta_all_of.rb', line 206 def valid? true end |