Class: OneSignal::SubscriptionNotificationTarget
- Inherits:
-
Object
- Object
- OneSignal::SubscriptionNotificationTarget
- Defined in:
- lib/onesignal/models/subscription_notification_target.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#email_to ⇒ Object
Recommended for Sending Emails - Target specific email addresses.
-
#include_aliases ⇒ Object
Target specific users by aliases assigned via API.
-
#include_amazon_reg_ids ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead.
-
#include_android_reg_ids ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead.
-
#include_chrome_reg_ids ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead.
-
#include_chrome_web_reg_ids ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead.
-
#include_email_tokens ⇒ Object
Deprecated alias for
email_to. -
#include_ios_tokens ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead.
-
#include_phone_numbers ⇒ Object
Recommended for Sending SMS - Target specific phone numbers.
-
#include_subscription_ids ⇒ Object
Specific subscription ids to send your notification to.
-
#include_wp_wns_uris ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead.
-
#target_channel ⇒ Object
Returns the value of attribute target_channel.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubscriptionNotificationTarget
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SubscriptionNotificationTarget
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OneSignal::SubscriptionNotificationTarget` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OneSignal::SubscriptionNotificationTarget`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'include_subscription_ids') if (value = attributes[:'include_subscription_ids']).is_a?(Array) self.include_subscription_ids = value end end if attributes.key?(:'include_email_tokens') if (value = attributes[:'include_email_tokens']).is_a?(Array) self.include_email_tokens = value end end if attributes.key?(:'email_to') if (value = attributes[:'email_to']).is_a?(Array) self.email_to = value end end if attributes.key?(:'include_phone_numbers') if (value = attributes[:'include_phone_numbers']).is_a?(Array) self.include_phone_numbers = value end end if attributes.key?(:'include_ios_tokens') if (value = attributes[:'include_ios_tokens']).is_a?(Array) self.include_ios_tokens = value end end if attributes.key?(:'include_wp_wns_uris') if (value = attributes[:'include_wp_wns_uris']).is_a?(Array) self.include_wp_wns_uris = value end end if attributes.key?(:'include_amazon_reg_ids') if (value = attributes[:'include_amazon_reg_ids']).is_a?(Array) self.include_amazon_reg_ids = value end end if attributes.key?(:'include_chrome_reg_ids') if (value = attributes[:'include_chrome_reg_ids']).is_a?(Array) self.include_chrome_reg_ids = value end end if attributes.key?(:'include_chrome_web_reg_ids') if (value = attributes[:'include_chrome_web_reg_ids']).is_a?(Array) self.include_chrome_web_reg_ids = value end end if attributes.key?(:'include_android_reg_ids') if (value = attributes[:'include_android_reg_ids']).is_a?(Array) self.include_android_reg_ids = value end end if attributes.key?(:'include_aliases') if (value = attributes[:'include_aliases']).is_a?(Hash) self.include_aliases = value end end if attributes.key?(:'target_channel') self.target_channel = attributes[:'target_channel'] end end |
Instance Attribute Details
#email_to ⇒ Object
Recommended for Sending Emails - Target specific email addresses. If an email does not correspond to an existing user, a new user will be created. Example: nick@catfac.ts. Limit of 2,000 entries per REST API call. Supersedes the deprecated include_email_tokens field.
24 25 26 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 24 def email_to @email_to end |
#include_aliases ⇒ Object
Target specific users by aliases assigned via API. An alias can be an external_id, onesignal_id, or a custom alias. Accepts an object where keys are alias labels and values are arrays of alias IDs to include Example usage: { "external_id": ["exId1", "extId2"], "internal_label": ["id1", "id2"] } Keys must match API spellings exactly (for example the label for External ID is the string external_id; arbitrary keys such as camelCase variants are not aliases and may yield no recipients). Not compatible with any other targeting parameters. REQUIRED: REST API Key Authentication Limit of 2,000 entries per REST API call Note: If targeting push, email, or sms subscribers with same ids, use with target_channel to indicate you are sending a push or email or sms.
48 49 50 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 48 def include_aliases @include_aliases end |
#include_amazon_reg_ids ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead. Target using Amazon ADM registration IDs. If a token does not correspond to an existing user, a new user will be created. Example: amzn1.adm-registration.v1.XpvSSUk0Rc3hTVVV... Limit of 2,000 entries per REST API call
36 37 38 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 36 def include_amazon_reg_ids @include_amazon_reg_ids end |
#include_android_reg_ids ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead. Target using Android device registration IDs. If a token does not correspond to an existing user, a new user will be created. Example: APA91bEeiUeSukAAUdnw3O2RB45FWlSpgJ7Ji_... Limit of 2,000 entries per REST API call
45 46 47 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 45 def include_android_reg_ids @include_android_reg_ids end |
#include_chrome_reg_ids ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead. Target using Chrome App registration IDs. If a token does not correspond to an existing user, a new user will be created. Example: APA91bEeiUeSukAAUdnw3O2RB45FWlSpgJ7Ji_... Limit of 2,000 entries per REST API call
39 40 41 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 39 def include_chrome_reg_ids @include_chrome_reg_ids end |
#include_chrome_web_reg_ids ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead. Target using Chrome Web Push registration IDs. If a token does not correspond to an existing user, a new user will be created. Example: APA91bEeiUeSukAAUdnw3O2RB45FWlSpgJ7Ji_... Limit of 2,000 entries per REST API call
42 43 44 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 42 def include_chrome_web_reg_ids @include_chrome_web_reg_ids end |
#include_email_tokens ⇒ Object
Deprecated alias for email_to. Target specific email addresses. If an email does not correspond to an existing user, a new user will be created. Example: nick@catfac.ts. Limit of 2,000 entries per REST API call. Prefer email_to in new integrations.
21 22 23 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 21 def include_email_tokens @include_email_tokens end |
#include_ios_tokens ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead. Target using iOS device tokens. Warning: Only works with Production tokens. All non-alphanumeric characters must be removed from each token. If a token does not correspond to an existing user, a new user will be created. Example: ce777617da7f548fe7a9ab6febb56cf39fba6d38203... Limit of 2,000 entries per REST API call
30 31 32 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 30 def include_ios_tokens @include_ios_tokens end |
#include_phone_numbers ⇒ Object
Recommended for Sending SMS - Target specific phone numbers. The phone number should be in the E.164 format. Phone number should be an existing subscriber on OneSignal. Refer our docs to learn how to add phone numbers to OneSignal. Example phone number: +1999999999 Limit of 2,000 entries per REST API call
27 28 29 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 27 def include_phone_numbers @include_phone_numbers end |
#include_subscription_ids ⇒ Object
Specific subscription ids to send your notification to. Does not require API Auth Key. Not compatible with any other targeting parameters. Example: ["1dd608f2-c6a1-11e3-851d-000c2940e62c"] Limit of 2,000 entries per REST API call
18 19 20 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 18 def include_subscription_ids @include_subscription_ids end |
#include_wp_wns_uris ⇒ Object
Not Recommended: Please consider using include_subscription_ids or include_aliases instead. Target using Windows URIs. If a token does not correspond to an existing user, a new user will be created. Example: http://s.notify.live.net/u/1/bn1/HmQAAACPaLDr-... Limit of 2,000 entries per REST API call
33 34 35 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 33 def include_wp_wns_uris @include_wp_wns_uris end |
#target_channel ⇒ Object
Returns the value of attribute target_channel.
50 51 52 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 50 def target_channel @target_channel end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 93 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 75 def self.attribute_map { :'include_subscription_ids' => :'include_subscription_ids', :'include_email_tokens' => :'include_email_tokens', :'email_to' => :'email_to', :'include_phone_numbers' => :'include_phone_numbers', :'include_ios_tokens' => :'include_ios_tokens', :'include_wp_wns_uris' => :'include_wp_wns_uris', :'include_amazon_reg_ids' => :'include_amazon_reg_ids', :'include_chrome_reg_ids' => :'include_chrome_reg_ids', :'include_chrome_web_reg_ids' => :'include_chrome_web_reg_ids', :'include_android_reg_ids' => :'include_android_reg_ids', :'include_aliases' => :'include_aliases', :'target_channel' => :'target_channel' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 268 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 120 121 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 116 def self.openapi_nullable Set.new([ :'include_subscription_ids', :'include_aliases', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 98 def self.openapi_types { :'include_subscription_ids' => :'Array<String>', :'include_email_tokens' => :'Array<String>', :'email_to' => :'Array<String>', :'include_phone_numbers' => :'Array<String>', :'include_ios_tokens' => :'Array<String>', :'include_wp_wns_uris' => :'Array<String>', :'include_amazon_reg_ids' => :'Array<String>', :'include_chrome_reg_ids' => :'Array<String>', :'include_chrome_web_reg_ids' => :'Array<String>', :'include_android_reg_ids' => :'Array<String>', :'include_aliases' => :'Hash<String, Array<String>>', :'target_channel' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && include_subscription_ids == o.include_subscription_ids && include_email_tokens == o.include_email_tokens && email_to == o.email_to && include_phone_numbers == o.include_phone_numbers && include_ios_tokens == o.include_ios_tokens && include_wp_wns_uris == o.include_wp_wns_uris && include_amazon_reg_ids == o.include_amazon_reg_ids && include_chrome_reg_ids == o.include_chrome_reg_ids && include_chrome_web_reg_ids == o.include_chrome_web_reg_ids && include_android_reg_ids == o.include_android_reg_ids && include_aliases == o.include_aliases && target_channel == o.target_channel end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 299 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OneSignal.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 370 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 275 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 261 def hash [include_subscription_ids, include_email_tokens, email_to, include_phone_numbers, include_ios_tokens, include_wp_wns_uris, include_amazon_reg_ids, include_chrome_reg_ids, include_chrome_web_reg_ids, include_android_reg_ids, include_aliases, target_channel].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
211 212 213 214 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 211 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
346 347 348 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 346 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 352 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
340 341 342 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 340 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
218 219 220 221 222 |
# File 'lib/onesignal/models/subscription_notification_target.rb', line 218 def valid? target_channel_validator = EnumAttributeValidator.new('String', ["push", "email", "sms"]) return false unless target_channel_validator.valid?(@target_channel) true end |