Class: OneSignal::UpdateLiveActivityRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/onesignal/models/update_live_activity_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateLiveActivityRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/onesignal/models/update_live_activity_request.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OneSignal::UpdateLiveActivityRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OneSignal::UpdateLiveActivityRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'event_updates')
    self.event_updates = attributes[:'event_updates']
  end

  if attributes.key?(:'contents')
    self.contents = attributes[:'contents']
  end

  if attributes.key?(:'headings')
    self.headings = attributes[:'headings']
  end

  if attributes.key?(:'sound')
    self.sound = attributes[:'sound']
  end

  if attributes.key?(:'stale_date')
    self.stale_date = attributes[:'stale_date']
  end

  if attributes.key?(:'dismissal_date')
    self.dismissal_date = attributes[:'dismissal_date']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end
end

Instance Attribute Details

#contentsObject

Returns the value of attribute contents.



25
26
27
# File 'lib/onesignal/models/update_live_activity_request.rb', line 25

def contents
  @contents
end

#dismissal_dateObject

Accepts Unix timestamp in seconds; only allowed if event is "end"



36
37
38
# File 'lib/onesignal/models/update_live_activity_request.rb', line 36

def dismissal_date
  @dismissal_date
end

#eventObject

Returns the value of attribute event.



20
21
22
# File 'lib/onesignal/models/update_live_activity_request.rb', line 20

def event
  @event
end

#event_updatesObject

This must match the ContentState interface you have defined within your Live Activity in your app.



23
24
25
# File 'lib/onesignal/models/update_live_activity_request.rb', line 23

def event_updates
  @event_updates
end

#headingsObject

Returns the value of attribute headings.



27
28
29
# File 'lib/onesignal/models/update_live_activity_request.rb', line 27

def headings
  @headings
end

#nameObject

An internal name to assist with your campaign organization. This does not get displayed in the message itself.



18
19
20
# File 'lib/onesignal/models/update_live_activity_request.rb', line 18

def name
  @name
end

#priorityObject

Delivery priority through the the push provider (APNs). Pass 10 for higher priority notifications, or 5 for lower priority notifications. Lower priority notifications are sent based on the power considerations of the end user's device. If not set, defaults to 10. Some providers (APNs) allow for a limited budget of high priority notifications per hour, and if that budget is exceeded, the provider may throttle notification delivery.



39
40
41
# File 'lib/onesignal/models/update_live_activity_request.rb', line 39

def priority
  @priority
end

#soundObject

Sound file that is included in your app to play instead of the default device notification sound. Omit to disable vibration and sound for the notification.



30
31
32
# File 'lib/onesignal/models/update_live_activity_request.rb', line 30

def sound
  @sound
end

#stale_dateObject

Accepts Unix timestamp in seconds. When time reaches the configured stale date, the system considers the Live Activity out of date, and the ActivityState of the Live Activity changes to ActivityState.stale.



33
34
35
# File 'lib/onesignal/models/update_live_activity_request.rb', line 33

def stale_date
  @stale_date
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/onesignal/models/update_live_activity_request.rb', line 79

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/onesignal/models/update_live_activity_request.rb', line 64

def self.attribute_map
  {
    :'name' => :'name',
    :'event' => :'event',
    :'event_updates' => :'event_updates',
    :'contents' => :'contents',
    :'headings' => :'headings',
    :'sound' => :'sound',
    :'stale_date' => :'stale_date',
    :'dismissal_date' => :'dismissal_date',
    :'priority' => :'priority'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
# File 'lib/onesignal/models/update_live_activity_request.rb', line 227

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/onesignal/models/update_live_activity_request.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/onesignal/models/update_live_activity_request.rb', line 84

def self.openapi_types
  {
    :'name' => :'String',
    :'event' => :'String',
    :'event_updates' => :'Object',
    :'contents' => :'LanguageStringMap',
    :'headings' => :'LanguageStringMap',
    :'sound' => :'String',
    :'stale_date' => :'Integer',
    :'dismissal_date' => :'Integer',
    :'priority' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/onesignal/models/update_live_activity_request.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      event == o.event &&
      event_updates == o.event_updates &&
      contents == o.contents &&
      headings == o.headings &&
      sound == o.sound &&
      stale_date == o.stale_date &&
      dismissal_date == o.dismissal_date &&
      priority == o.priority
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/onesignal/models/update_live_activity_request.rb', line 258

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = OneSignal.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/onesignal/models/update_live_activity_request.rb', line 329

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/onesignal/models/update_live_activity_request.rb', line 234

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/onesignal/models/update_live_activity_request.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/onesignal/models/update_live_activity_request.rb', line 220

def hash
  [name, event, event_updates, contents, headings, sound, stale_date, dismissal_date, priority].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/onesignal/models/update_live_activity_request.rb', line 158

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @event_updates.nil?
    invalid_properties.push('invalid value for "event_updates", event_updates cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
# File 'lib/onesignal/models/update_live_activity_request.rb', line 305

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/onesignal/models/update_live_activity_request.rb', line 311

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



299
300
301
# File 'lib/onesignal/models/update_live_activity_request.rb', line 299

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
184
# File 'lib/onesignal/models/update_live_activity_request.rb', line 177

def valid?
  return false if @name.nil?
  return false if @event.nil?
  event_validator = EnumAttributeValidator.new('String', ["update", "end"])
  return false unless event_validator.valid?(@event)
  return false if @event_updates.nil?
  true
end